@@ -39,9 +39,7 @@ package Imager::CommandLine::FindImage {
 
     my @cols = @{ $self->_cols };
 
-    my $table = Imager::TabularDisplay::generate_table(\@cols, \@res);
-    
-    print($table->render, "\n");
+    Imager::TabularDisplay::print_table(\@cols, \@res);
   }
 }
 
